@@ -10,7 +10,7 @@
 #'   `from` will be copied to `to`.
 #' @param to A `SQLiteConnection` object pointing to an empty database.
 #' @author Seth Falcon
-#' @references \url{http://www.sqlite.org/backup.html}
+#' @references \url{https://www.sqlite.org/backup.html}
 #' @export
 #' @examples
 #' library(DBI)
@@ -34,6 +34,6 @@ sqliteCopyDatabase <- function(from, to) {
   if (!is(to, "SQLiteConnection"))
     stop("'to' must be a SQLiteConnection object")
 
-  rsqlite_copy_database(from@ptr, to@ptr)
+  connection_copy_database(from@ptr, to@ptr)
   invisible(NULL)
 }
