@@ -1,7 +1,7 @@
 #' Add useful extension functions
 #'
 #' These extension functions are written by Liam Healy and made available
-#' through the SQLite website (\url{http://www.sqlite.org/contrib}).
+#' through the SQLite website (\url{https://www.sqlite.org/contrib}).
 #'
 #' @section Available extension functions:
 #'
@@ -30,8 +30,12 @@ initExtension <- function(db) {
       call. = FALSE)
   }
 
-  lib_path <- getLoadedDLLs()[["RSQLite"]][["path"]]
-  res <- dbGetQuery(db, sprintf("SELECT load_extension('%s')", lib_path))
+  extension_load(db@ptr, get_lib_path(), "sqlite3_math_init")
 
   invisible(TRUE)
 }
+
+get_lib_path <- function() {
+  lib_path <- getLoadedDLLs()[["RSQLite"]][["path"]]
+  enc2utf8(lib_path)
+}
