@@ -6,9 +6,10 @@
 
 class SqliteColumnDataSourceFactory : public DbColumnDataSourceFactory {
   sqlite3_stmt* stmt;
+  bool with_alt_types;
 
 public:
-  SqliteColumnDataSourceFactory(sqlite3_stmt* stmt_);
+  SqliteColumnDataSourceFactory(sqlite3_stmt* stmt_, bool with_alt_types_);
   ~SqliteColumnDataSourceFactory();
 
 public:
