@@ -3,9 +3,13 @@
 
 
 #include <boost/noncopyable.hpp>
+#include <boost/shared_ptr.hpp>
 #include "sqlite3.h"
 #include "DbColumnDataType.h"
 
+class DbConnection;
+typedef boost::shared_ptr<DbConnection> DbConnectionPtr;
+
 class SqliteResultImpl : public boost::noncopyable {
 private:
   // Wrapped pointer
@@ -31,9 +35,10 @@ private:
   List params_;
   int group_, groups_;
   std::vector<DATA_TYPE> types_;
+  bool with_alt_types_;
 
 public:
-  SqliteResultImpl(sqlite3* conn_, const std::string& sql);
+  SqliteResultImpl(const DbConnectionPtr& conn_, const std::string& sql);
   ~SqliteResultImpl();
 
 private:
