@@ -15,12 +15,12 @@ extern "C" {
 
 // [[Rcpp::export]]
 XPtr<DbConnectionPtr> connection_connect(
-  const std::string& path, const bool allow_ext, const int flags, const std::string& vfs = ""
+  const std::string& path, const bool allow_ext, const int flags, const std::string& vfs = "", bool with_alt_types = false
 ) {
   LOG_VERBOSE;
 
   DbConnectionPtr* pConn = new DbConnectionPtr(
-    new DbConnection(path, allow_ext, flags, vfs)
+    new DbConnection(path, allow_ext, flags, vfs, with_alt_types)
   );
 
   return XPtr<DbConnectionPtr>(pConn, true);
